from charms.reactive import when, when_not, set_flag
from charmhelpers.core import hookenv, host
from charmhelpers.contrib.charmsupport import nrpe
from charmhelpers import fetch
import os


@when_not('infra-node.installed')
def install_maas_node():
    set_flag('infra-node.installed')


@when('nrpe-external-master.available')
def update_nrpe_config():
    # python-dbus is used by check_upstart_job
    fetch.apt_install('python-dbus', fatal=True)
    hostname = nrpe.get_nagios_hostname()
    current_unit = nrpe.get_nagios_unit_name()
    nrpe_setup = nrpe.NRPE(hostname=hostname)
    services = ['maas-dhcpd', 'maas-rackd', 'bind9']
    nrpe.add_init_service_checks(nrpe_setup, services, current_unit)
    nrpe_setup.add_check(
            'juju_disabled_commands',
            'Check that Juju commands are disabled',
            '/usr/local/lib/nagios/plugins/check_juju_disabled_commands -f /home/jujumanage/juju_commands_state.txt'
            )
    nrpe_setup.write()
    command = "/snap/bin/juju disabled-commands > ${HOME?}/juju_commands_state.txt"
    CRONJOB_CMD = (" * * * * * jujumanage timeout -k 10s -s SIGINT 60 "
                   "{command} 2>&1 | logger -p local0.notice\n")
    cronjob = CRONJOB_CMD.format(command=command)
    host.write_file('/etc/cron.d/juju_disabled_commands', cronjob)

    charm_file_dir = os.path.join(hookenv.charm_dir(), 'files')
    charm_plugin_dir = os.path.join(charm_file_dir, 'plugins')
    host.rsync(
        charm_plugin_dir,
        '/usr/local/lib/nagios/',
        options=['--executability']
        )

    hookenv.status_set('active', 'NRPE configured')
